==> blesta-5.10.2.zip: blesta/core/Automation/Tasks/Task/language/cs_cz/cleanup_logs.php <==
<?php
/**
 * Cleanup Logs
 *
 * @package blesta
 * @subpackage blesta.language.cs_cz
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['Automation.task.cleanup_logs.logs_cron_deleted'] = '%1$s staré protokoly Cron byly odstraněny.';
$lang['Automation.task.cleanup_logs.logs_transaction_deleted'] = '%1$s staré transakční protokoly byly odstraněny.';
$lang['Automation.task.cleanup_logs.logs_service_deleted'] = '%1$s staré protokoly služby byly odstraněny.';
$lang['Automation.task.cleanup_logs.logs_client_settings_deleted'] = '%1$s staré protokoly nastavení klienta byly odstraněny.';
$lang['Automation.task.cleanup_logs.logs_user_deleted'] = '%1$s staré protokoly uživatele byly odstraněny.';
$lang['Automation.task.cleanup_logs.logs_messenger_deleted'] = '%1$s staré protokoly služby Messenger byly odstraněny.';
$lang['Automation.task.cleanup_logs.logs_email_deleted'] = '%1$s staré protokoly e-mailu byly odstraněny.';
$lang['Automation.task.cleanup_logs.logs_contact_deleted'] = '%1$s staré protokoly kontaktů byly odstraněny.';
$lang['Automation.task.cleanup_logs.logs_accountaccess_deleted'] = '%1$s staré protokoly o přístupu k účtu byly odstraněny.';
$lang['Automation.task.cleanup_logs.logs_module_deleted'] = '%1$s staré protokoly modulu byly odstraněny.';
$lang['Automation.task.cleanup_logs.logs_gateway_deleted'] = '%1$s staré protokoly brány byly odstraněny.';
$lang['Automation.task.cleanup_logs.completed'] = 'Úloha čištění protokolů byla dokončena.';
$lang['Automation.task.cleanup_logs.attempt'] = 'Pokus o vyčištění starých protokolů.';

==> blesta-5.11.4.zip: blesta/core/Automation/Tasks/Task/language/cs_cz/cleanup_logs.php <==
<?php
/**
 * Cleanup Logs
 *
 * @package blesta
 * @subpackage blesta.language.cs_cz
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['Automation.task.cleanup_logs.logs_cron_deleted'] = '%1$s staré protokoly Cron byly odstraněny.';
$lang['Automation.task.cleanup_logs.logs_transaction_deleted'] = '%1$s staré transakční protokoly byly odstraněny.';
$lang['Automation.task.cleanup_logs.logs_service_deleted'] = '%1$s staré protokoly služby byly odstraněny.';
$lang['Automation.task.cleanup_logs.logs_client_settings_deleted'] = '%1$s staré protokoly nastavení klienta byly odstraněny.';
$lang['Automation.task.cleanup_logs.logs_user_deleted'] = '%1$s staré protokoly uživatele byly odstraněny.';
$lang['Automation.task.cleanup_logs.logs_messenger_deleted'] = '%1$s staré protokoly služby Messenger byly odstraněny.';
$lang['Automation.task.cleanup_logs.logs_email_deleted'] = '%1$s staré protokoly e-mailu byly odstraněny.';
$lang['Automation.task.cleanup_logs.logs_contact_deleted'] = '%1$s staré protokoly kontaktů byly odstraněny.';
$lang['Automation.task.cleanup_logs.logs_accountaccess_deleted'] = '%1$s staré protokoly o přístupu k účtu byly odstraněny.';
$lang['Automation.task.cleanup_logs.logs_module_deleted'] = '%1$s staré protokoly modulu byly odstraněny.';
$lang['Automation.task.cleanup_logs.logs_gateway_deleted'] = '%1$s staré protokoly brány byly odstraněny.';
$lang['Automation.task.cleanup_logs.completed'] = 'Úloha čištění protokolů byla dokončena.';
$lang['Automation.task.cleanup_logs.attempt'] = 'Pokus o vyčištění starých protokolů.';
$lang['Automation.task.cleanup_logs.logs_service_changes_deleted'] = '%1$s staré protokoly o změnách služby byly odstraněny.';
